## ------------------------------------------------------------------------
library(RGeostats)
rg.load("Exdemo_1D_well.table","well.table",flag.overwrite=TRUE)

## ------------------------------------------------------------------------
well.db <- db.create(well.table,flag.grid=TRUE,x0=519.00074,dx=0.02002,nx=850,
                     autoname=FALSE)

## ------------------------------------------------------------------------
print(well.db)

## ------------------------------------------------------------------------
well.db <- db.locate(well.db,4,"z",1)

## ------------------------------------------------------------------------
well.db <- db.delete(well.db,3)

## ------------------------------------------------------------------------
well.db

## ------------------------------------------------------------------------
print(well.db,flag.stats=T)

## ------------------------------------------------------------------------
plot(well.db)

## ----Compute_Variogram---------------------------------------------------
well.vario <- vario.grid(well.db,nlag=500)

## ----Print_Variogram, eval=FALSE-----------------------------------------
## print(well.vario)

## ----Plot_Variogram------------------------------------------------------
plot(well.vario,title="Variogram of Conductivity")

## ----Model_Fitting-------------------------------------------------------
well.model = model.auto(well.vario,
                        struct=c("Cosexp","Cosexp",
                                 "Cosexp","Linear"),
                        title="Model of Conductivity",verbose=TRUE)

## ----Print_Model---------------------------------------------------------
print(well.model)

## ----Create_Neighborhood-------------------------------------------------
well.neigh <- neigh.create(ndim=1, type=3, radimg=100, skip=1)

## ----Print_Neighborhood--------------------------------------------------
print(well.neigh)

## ----Filtering-----------------------------------------------------------
well.db <- krimage(well.db,model=well.model,neigh=well.neigh,
                   cov.extract=1,
                   drift.extract=0,radix="s1",modify.target=FALSE)

## ----Filtering_all_components, echo=FALSE--------------------------------
well.db <- krimage(well.db,model=well.model,neigh=well.neigh,cov.extract=2,
                   drift.extract=0,radix="s2",modify.target=FALSE)
well.db <- krimage(well.db,model=well.model,neigh=well.neigh,cov.extract=3,
                   drift.extract=0,radix="s3",modify.target=FALSE)
well.db <- krimage(well.db,model=well.model,neigh=well.neigh,cov.extract=4,
                   drift.extract=0,radix="s4",modify.target=FALSE)

## ----Filtering_Mean------------------------------------------------------
well.db <- krimage(well.db,model=well.model,neigh=well.neigh,
                   cov.extract=0,drift.extract=1,radix="sm",
		   modify.target=FALSE)

## ----Print_Results-------------------------------------------------------
print(well.db)

## ----Visualize_Results---------------------------------------------------
plot(well.db,name="s1.Conductivity.estim")
plot(well.db,name="s2.Conductivity.estim")
plot(well.db,name="s3.Conductivity.estim")
plot(well.db,name="s4.Conductivity.estim")
plot(well.db,name="sm.Conductivity.estim")

## ----Ultimate_check------------------------------------------------------
well.db <- db.add(well.db,Sum=s1.Conductivity.estim+s2.Conductivity.estim+
		  s3.Conductivity.estim+s4.Conductivity.estim+
                  sm.Conductivity.estim)

## ----Correlation---------------------------------------------------------
dummy = correlation(well.db,"Conductivity","Sum")

