## ----Setup, include=FALSE------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ----Loading Library,message=FALSE, echo=FALSE---------------------------
library(RGeostats)
rm(list=ls())
constant.define("asp",1)

## ----Loading Exdemo_autofit1.model---------------------------------------
data(Exdemo_autofit1.model)

## ----Sampling Variogram #1-----------------------------------------------
vario <- model.sample(Exdemo_autofit1.model,lag=0.1,nlag=100)

## ----Plot_Model_1--------------------------------------------------------
plot(vario,title="Isotropic Variogram to be Fitted")

## ----Fitting_Model_1-----------------------------------------------------
model <- model.auto(vario,maxiter=100,title="Isotropic Model")

## ----Clean #1,echo=FALSE-------------------------------------------------
rm(vario,model,pos=1)

## ----Loading Exdemo_autofit2.model---------------------------------------
data(Exdemo_autofit2.model)
vario <- model.sample(Exdemo_autofit2.model,lag=0.1,nlag=100,
      dirvect=c(0,45,90,135))
plot(vario,title="Anisotropic Variogram to be Fitted")

## ----Fitting_Model_2-----------------------------------------------------
model <- model.auto(vario,maxiter=500,
                    title="Anisotropic Model")
print(model)

## ----Clean #2, echo=FALSE------------------------------------------------
rm(vario,model,pos=1)

## ----Loading Exdemo_autofit3.vario---------------------------------------
data(Exdemo_autofit3.vario)
plot(Exdemo_autofit3.vario,
	title="Variogram in 2-D space to be Fitted")

## ----Fitting_Model_3-----------------------------------------------------
model <- model.auto(Exdemo_autofit3.vario,maxiter=200,
        title="Model in 2-D space")
model

## ----Clean #3, echo=FALSE------------------------------------------------
rm(model,pos=1)

## ----Loading Exdemo_autofit4.vario---------------------------------------
data(Exdemo_autofit4.vario)
plot(Exdemo_autofit4.vario,
     title="Variogram in 3-D space to be Fitted")

## ----Fitting_Model_4-----------------------------------------------------
model <- model.auto(Exdemo_autofit4.vario,maxiter=100,
        title="Model in 3-D space")

## ----Cleaning #4, echo=FALSE---------------------------------------------
rm(model,pos=1)

## ----Loading Exdemo_autofit5.vario---------------------------------------
data(Exdemo_autofit5.vario)

## ----Plotting_5----------------------------------------------------------
plot(Exdemo_autofit5.vario)

## ----Fiting_Model_5------------------------------------------------------
model <- model.auto(Exdemo_autofit5.vario,maxiter=100,
                    draw=FALSE)

## ----Plotting_Result_5---------------------------------------------------
plot(Exdemo_autofit5.vario,varcols=seq(1,5))
plot(model,Exdemo_autofit5.vario,varcols=seq(1,5),add=T)

## ----Cleaning #5, echo=FALSE---------------------------------------------
rm(model,pos=1)

## ----Loading Exdemo_autofit6.vario---------------------------------------
data(Exdemo_autofit6.vario)
plot(Exdemo_autofit6.vario,
	title="Directional variograms on the grid")

## ----Fitting_Model_6.a---------------------------------------------------
model <- model.auto(Exdemo_autofit6.vario,maxiter=100,
        title="Directional Model on the grid")

## ----Fitting_Model_6.b---------------------------------------------------
model <- model.auto(Exdemo_autofit6.vario,maxiter=100,
      struct=melem.name(c(3,3,3)),title="Fitting with 3 sphericals")

## ----Clean #6, echo=FALSE------------------------------------------------
rm(model,pos=1)

## ----creating Grid #7----------------------------------------------------
grid <- db.create(nx=c(200,200))

## ----Loading Exdemo_autofit7.model---------------------------------------
data(Exdemo_autofit7.model)

## ----Performing Simulation-----------------------------------------------
grid  <- simtub(,grid,Exdemo_autofit7.model)

## ----Plot_Simulation_Outcome---------------------------------------------
plot(grid,title="Simulation Outcome")

## ----Vmap calculation #7-------------------------------------------------
vmap  <- vmap.grid(grid,nx=30,ny=30,flag.fft=TRUE)

## ----Plot_Experimental_Vmap_7--------------------------------------------
plot(vmap,title="Experimental Vmap")

## ----Fitting_Vmap_7------------------------------------------------------
model <- vmap.auto(vmap,maxiter=100,
                   struct=melem.name(c(1,3,3)))

## ----Clean #7, echo=FALSE------------------------------------------------
rm(grid,model,vmap,pos=1)

