## ----Loading Library, echo=FALSE, message=FALSE--------------------------
library(RGeostats)
constant.define("asp",1)
rm(list=ls())

## ----Loading Data--------------------------------------------------------
rg.load("Exdemo_Filter","grid")

## ----Statistics----------------------------------------------------------
print(grid,flag.stats=TRUE,names=c("P","Cr","Ni"))

## ----Correlation_Cr_P----------------------------------------------------
correlation(grid,"Cr","P",title="Correlation between P and Cr")

## ----Correlation_Ni_P----------------------------------------------------
correlation(grid,"Ni","P",title="Correlation between P and Ni")

## ----Correlation_Ni_Cr---------------------------------------------------
correlation(grid,"Ni","Cr",title="Correlation between Cr and Ni")

## ----Completing P--------------------------------------------------------
grid = db.locate(grid,"P","z")
grid = db.grid.fill(grid,radix="P.Fill")

## ----Locate P------------------------------------------------------------
grid = db.locate(grid,"P.Fill","z")

## ----Monovariate_Variogram_calculation-----------------------------------
varioP = vario.grid(grid,nlag=100)
modelP = model.auto(varioP,struct=c(1,2,12),
                    auth.aniso = FALSE,flag.noreduce=TRUE)
modelP

## ----Visualize_P---------------------------------------------------------
plot(grid,pos.legend=1,title="P after completion")

## ----Neighborhood Definition---------------------------------------------
neigh = neigh.create(ndim=2,type=3,radimg=c(10,10))

## ----Performing the monovariate FKA--------------------------------------
means = db.stat(grid,flag.mono=TRUE,names="P.Fill")
mono = krimage(grid,modelP,neigh,cov.extract = c(2,3),uc="",
               mean = means)

## ----Visualize_P_after_FKA_monovariate-----------------------------------
plot(mono,pos.legend=1,title="P denoised (monovariate)",
     zlim=c(0,150))

## ----Locate Multivariate-------------------------------------------------
grid = db.locate(grid,c("P.Fill","Cr","Ni"),"z")

## ----Multivariate_Variogram_calculation----------------------------------
varioM = vario.grid(grid,nlag=100)
modelM = model.auto(varioM,struct=c(1,2,12),
                    auth.aniso = FALSE,flag.noreduce=TRUE)
modelM

## ----Perform multivariate FKA--------------------------------------------
means = db.stat(grid,flag.mono=TRUE,names=c("P.Fill","Cr","Ni"))
multi = krimage(grid,modelM,neigh,cov.extract = c(2,3),uc="",
                mean = means)

## ----Visualize_P_after_FKA_multivariate----------------------------------
plot(multi,pos.legend=1,title="P denoised (multivariate)",
     zlim=c(0,150))

