## ----Loading Libraries, message=FALSE, warning=FALSE---------------------
library(RGeostats)

## ----Main parameters-----------------------------------------------------
  ndim <- 2
  nvar <- 1

## ----Graphics------------------------------------------------------------

                                        # List of the authorized structures #
  list    <- melem.name(degree=0)
  nstruct <- length(list)
  param   <- 1.2
  sill    <- 1

                                        # Loop on the authorized structures #
  for (rank in 1:nstruct) {
    vartype  <- list[rank]
    res      <- melem.characteristics(vartype,ndim=ndim)
    if (res$flag.param && param > res$parmax) param = res$parmax
    
    cat("Structure: ",vartype,"\n")
    if (res$flag.range) cat("Range parameter is available\n")
    if (res$flag.param) cat("Third parameter is available\n")
    cat("Structure may be used for degree of IRF >=",res$min.order,"\n")
    cat("Structure may be used for space dimension <=",res$max.ndim,"\n")
    if (res$flag.int.1d)   cat("Integral range is defined in 1-D\n")
    if (res$flag.int.2d)   cat("Integral range is defined in 2-D\n")
    if (res$flag.aniso)    cat("Anisotropy can be defined\n")
    if (res$flag.rotation) cat("Anisotropy rotation can be defined\n")
    if (res$flag.param)    cat("Third parameter must be < ",res$parmax,"\n")
    
    
    model    <- model.create(vartype, param=param, sill=sill) 
    plot(model,title=vartype)
  }

