## ------------------------------------------------------------------------
library(RGeostats)

## ----Grid creation-------------------------------------------------------
constant.define("asp",1)
grid = db.create(nx=c(500,300))

## ----Initial Simulation--------------------------------------------------
model = model.create(vartype="Cubic",range=40)
grid = simtub(,grid,model,nbtuba=1000,seed=3213)
grid = db.rename(grid,grid$natt,"Simulation")
plot(grid)

## ----Binary Image--------------------------------------------------------
grid = morpho(grid,vmin=0,oper="thresh")
grid = db.rename(grid,grid$natt,"Binary")
plot(grid)

## ----Erosion-------------------------------------------------------------
radius = 1
option = 0
grid = db.locate(grid,"Simulation","z")
grid = morpho(grid,vmin=0,oper="erode",option=option,radius=radius)
grid = db.rename(grid,grid$natt,"Erosion")
plot(grid)

## ----Dilation------------------------------------------------------------
grid = db.locate(grid,"Simulation","z")
grid = morpho(grid,vmin=0,oper="dilate",option=option,radius=radius)
grid = db.rename(grid,grid$natt,"Dilation")
plot(grid)

## ----Edge----------------------------------------------------------------
grid = db.add(grid,Dilation-Erosion)
grid = db.rename(grid,grid$natt,"Edge")
plot(grid)

## ----Opening-------------------------------------------------------------
grid = db.locate(grid,"Simulation","z")
grid = morpho(grid,vmin=0,oper="open",option=option,radius=radius)
grid = db.rename(grid,grid$natt,"Opening")
plot(grid)

## ----Closing-------------------------------------------------------------
grid = db.locate(grid,"Simulation","z")
grid = morpho(grid,vmin=0,oper="close",option=option,radius=radius)
grid = db.rename(grid,grid$natt,"Closing")
plot(grid)

## ----Erosion Block-------------------------------------------------------
radius = 1
option = 1
grid = db.locate(grid,"Simulation","z")
grid = morpho(grid,vmin=0,oper="erode",option=option,radius=radius)
grid = db.rename(grid,grid$natt,"Erosion.Block")
plot(grid)

## ----Erosion iterated----------------------------------------------------
niter=5
grid = db.locate(grid,"Simulation","z")
grid = morpho(grid,vmin=0,oper="erode",option=option,radius=radius,
              niter=niter)
grid = db.rename(grid,grid$natt,"Erosion_iterated")
plot(grid,title=paste0("Erosion (x",niter,")"))

## ----Connect components--------------------------------------------------
grid = db.locate(grid,"Erosion_iterated","z")
grid = morpho(grid,vmin=0.5,oper="ccsize")
grid = db.rename(grid,grid$natt,"Connected components")
plot(grid)

## ----Distance to Edge----------------------------------------------------
grid = db.locate(grid,"Erosion_iterated","z")
grid = morpho(grid,vmin=0.5,oper="dist")
grid = db.rename(grid,grid$natt,"Distance to Edge")
plot(grid)

