## ----setup, include=FALSE------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ----Loading Library, message=FALSE, echo=FALSE--------------------------
library(RGeostats)
rm(list=ls())

## ----Creating Grid-------------------------------------------------------
outgrid1<-db.create(flag.grid=T,x0=c(0,0),nx=c(200,100),dx=c(1,1))

## ----Defining color map--------------------------------------------------
pal4fac <- c("red","orange","green","blue")

## ----Defining Lithotype Rule---------------------------------------------
rule4fac = rule.create(c("S","F1","T","F2","S","F3","F4"))

## ----Visualizing Lithotype Rule------------------------------------------
plot (rule4fac,col=pal4fac)

## ------------------------------------------------------------------------
modY1 = model.create(vartype="Cubic",sill=1,aniso.angles=-60,range=c(35,20))
modY2 = model.create(vartype="Exponential",sill=1,range=15)

## ----Checking First Model------------------------------------------------
modY1

## ----Checking Second Model-----------------------------------------------
modY2

## ----Performing PGS------------------------------------------------------
outgrid1 <- simpgs(dbout=outgrid1,rule=rule4fac,
                   model1=modY1,model2=modY2,props=c(0.25,0.25,0.25,0.25),
                   nbsimu=1,nbtuba=600,seed=126543) 

## ----Representing Stationary PGS Simulation------------------------------
plot(outgrid1,col=pal4fac,flag.scale=TRUE,
     title="Stationary PluriGaussian Simulation")

## ----Creating second Grid------------------------------------------------
outgrid2<-db.create(flag.grid=TRUE,x0=c(0,0),nx=c(200,100),dx=c(1,1))

## ----Creating proportions------------------------------------------------
outgrid2 <- db.add(outgrid2,Prop1=x1/200) 
outgrid2 <- db.add(outgrid2,Prop2=0.1*(1-Prop1)) 
outgrid2 <- db.add(outgrid2,Prop3=0.5*(1-Prop1-Prop2)) 
outgrid2 <- db.add(outgrid2,Prop4=1-Prop1-Prop2-Prop3) 

## ----Defining Proportion Locators----------------------------------------
outgrid2 <- db.locate(outgrid2,seq(4,7),loctype="p")
outgrid2

## ----Displaying Proportions----------------------------------------------
plot(outgrid2,name="Prop1",pos.legend=1,
     title="Proportion of First Lithotype")
plot(outgrid2,name="Prop4",pos.legend=1,
     title="Proportion of fourth Lithotype")

## ----Non-stationary PluriGaussian Simulation-----------------------------
outgrid2 <- simpgs(dbout=outgrid2, rule=rule4fac, dbprop=outgrid2,
                   model1=modY1,model2=modY2, nbsimu=1,
                   nbtuba=600,seed=126543,verbose=TRUE) 

## ----Representing Non-Stationary PGS Simulation--------------------------
plot(outgrid2,col=pal4fac,flag.scale=TRUE,
          title="Non Stationary PluriGaussian Simulation")

